@@ -14,3 +14,6 @@
 
 #undef AUTOUPGRADE
 
+#undef WITH_TARTY_WARP
+
+#undef WITH_ZOOM
