@@ -25,10 +25,11 @@
 /* Parse a C expression from text in a string  */
 
 #include "config.h"
-#include "cpplib.h"
+#include "header.h"
 
-extern char        *xmalloc PARAMS((unsigned));
-extern char        *xrealloc PARAMS((char *, unsigned));
+#ifdef __EMX__
+#include <strings.h>
+#endif
 
 #ifdef MULTIBYTE_CHARS
 #include <locale.h>
@@ -36,12 +37,13 @@ extern char        *xrealloc PARAMS((char *, unsigned));
 
 #include <stdlib.h>
 #include <stdio.h>
+#include <string.h>
 
 /* This is used for communicating lists of keywords with cccp.c.  */
 struct arglist
   {
      struct arglist     *next;
-     U_CHAR             *name;
+     unsigned char             *name;
      int                 length;
      int                 argno;
   };
@@ -64,8 +66,6 @@ struct arglist
 #define NULL_PTR ((GENERIC_PTR)0)
 #endif
 
-extern char        *xmalloc();
-
 #ifndef CHAR_TYPE_SIZE
 #define CHAR_TYPE_SIZE BITS_PER_UNIT
 #endif
@@ -127,18 +127,6 @@ static long         right_shift();
 #define SKIP_OPERAND 8
 /*#define UNSIGNEDP 16 */
 
-#ifndef HOST_BITS_PER_WIDE_INT
-
-#if HOST_BITS_PER_LONG > HOST_BITS_PER_INT
-#define HOST_BITS_PER_WIDE_INT HOST_BITS_PER_LONG
-#define HOST_WIDE_INT long
-#else
-#define HOST_BITS_PER_WIDE_INT HOST_BITS_PER_INT
-#define HOST_WIDE_INT int
-#endif
-
-#endif
-
 struct operation
   {
      short               op;
@@ -147,7 +135,7 @@ struct operation
      char                unsignedp;	/* true if value should be treated as unsigned */
      HOST_WIDE_INT       value;	/* The value logically "right" of op. */
   };
-
+
 /* Take care of parsing a number (anything that starts with a digit).
  * LEN is the number of characters in it.  */
 
@@ -160,13 +148,13 @@ parse_number(pfile, start, olen)
      int                 olen;
 {
    struct operation    op;
-   register char      *p = start;
-   register int        c;
-   register unsigned long n = 0, nd, ULONG_MAX_over_base;
-   register int        base = 10;
-   register int        len = olen;
-   register int        overflow = 0;
-   register int        digit, largest_digit = 0;
+   char      *p = start;
+   int        c;
+   unsigned long n = 0, nd, ULONG_MAX_over_base;
+   int        base = 10;
+   int        len = olen;
+   int        overflow = 0;
+   int        digit, largest_digit = 0;
    int                 spec_long = 0;
 
    op.unsignedp = 0;
@@ -232,7 +220,7 @@ parse_number(pfile, start, olen)
 	if (largest_digit < digit)
 	   largest_digit = digit;
 	nd = n * base + digit;
-	overflow |= ULONG_MAX_over_base < n | nd < n;
+	overflow |= (ULONG_MAX_over_base < n) | (nd < n);
 	n = nd;
      }
 
@@ -287,12 +275,11 @@ struct operation
 cpp_lex(pfile)
      cpp_reader         *pfile;
 {
-   register int        c;
-   register int        namelen;
-   register struct token *toktab;
+   int        c;
+   struct token *toktab;
    enum cpp_token      token;
    struct operation    op;
-   U_CHAR             *tok_start, *tok_end;
+   unsigned char             *tok_start, *tok_end;
    int                 old_written;
 
  retry:
@@ -330,7 +317,7 @@ cpp_lex(pfile)
      case CPP_COMMENT:
 	goto retry;
      case CPP_NUMBER:
-	return parse_number(pfile, tok_start, tok_end - tok_start);
+	return parse_number(pfile, (char *)tok_start, tok_end - tok_start);
      case CPP_STRING:
 	cpp_error(pfile, "string constants not allowed in #if expressions");
 	op.op = ERROR;
@@ -340,12 +327,12 @@ cpp_lex(pfile)
 	 * handles multicharacter constants and wide characters.
 	 * It is mostly copied from c-lex.c.  */
 	{
-	   register int        result = 0;
-	   register            num_chars = 0;
+	   int        result = 0;
+	   int        num_chars = 0;
 	   unsigned            width = MAX_CHAR_TYPE_SIZE;
 	   int                 wide_flag = 0;
 	   int                 max_chars;
-	   U_CHAR             *ptr = tok_start;
+	   unsigned char             *ptr = tok_start;
 
 #ifdef MULTIBYTE_CHARS
 	   char                token_buffer[MAX_LONG_TYPE_SIZE / MAX_CHAR_TYPE_SIZE + MB_CUR_MAX];
@@ -376,9 +363,9 @@ cpp_lex(pfile)
 
 		if (c == '\\')
 		  {
-		     c = cpp_parse_escape(pfile, &ptr);
+		     c = cpp_parse_escape(pfile, (char **)&ptr);
 		     if (width < HOST_BITS_PER_INT
-			 && (unsigned)c >= (1 << width))
+			 && (unsigned)c >= (unsigned)(1 << width))
 			cpp_pedwarn(pfile,
 				"escape sequence out of range for character");
 		  }
@@ -502,7 +489,7 @@ cpp_parse_escape(pfile, string_ptr)
      cpp_reader         *pfile;
      char              **string_ptr;
 {
-   register int        c = *(*string_ptr)++;
+   int        c = *(*string_ptr)++;
 
    switch (c)
      {
@@ -540,8 +527,8 @@ cpp_parse_escape(pfile, string_ptr)
      case '6':
      case '7':
 	{
-	   register int        i = c - '0';
-	   register int        count = 0;
+	   int        i = c - '0';
+	   int        count = 0;
 
 	   while (++count < 3)
 	     {
@@ -564,7 +551,7 @@ cpp_parse_escape(pfile, string_ptr)
 	}
      case 'x':
 	{
-	   register unsigned   i = 0, overflow = 0, digits_found = 0, digit;
+	   unsigned   i = 0, overflow = 0, digits_found = 0, digit;
 
 	   for (;;)
 	     {
@@ -639,14 +626,21 @@ right_shift(pfile, a, unsignedp, b)
      int                 unsignedp;
      unsigned long       b;
 {
+   pfile = NULL;
    if (b >= HOST_BITS_PER_LONG)
-      return unsignedp ? 0 : a >> (HOST_BITS_PER_LONG - 1);
+     {
+	return unsignedp ? 0 : a >> (HOST_BITS_PER_LONG - 1);
+     }
    else if (unsignedp)
-      return (unsigned long)a >> b;
+     {
+	return (unsigned long)a >> b;
+     }
    else
-      return a >> b;
+     {
+	return a >> b;
+     }
 }
-
+
 /* These priorities are all even, so we can handle associatively. */
 #define PAREN_INNER_PRIO 0
 #define COMMA_PRIO 4
@@ -666,7 +660,7 @@ right_shift(pfile, a, unsignedp, b)
 
 #define COMPARE(OP) \
   top->unsignedp = 0;\
-  top->value = (unsigned1 || unsigned2) ? (unsigned long) v1 OP v2 : (v1 OP v2)
+  top->value = (unsigned1 || unsigned2) ? (unsigned long) v1 OP (unsigned long) v2 : (v1 OP v2)
 
 /* Parse and evaluate a C expression, reading from PFILE.
  * Returns the value of the expression.  */
@@ -689,8 +683,8 @@ cpp_parse_expr(pfile)
    struct operation    init_stack[INIT_STACK_SIZE];
    struct operation   *stack = init_stack;
    struct operation   *limit = stack + INIT_STACK_SIZE;
-   register struct operation *top = stack;
-   int                 lprio, rprio;
+   struct operation *top = stack;
+   int                 lprio = 0, rprio = 0;
    int                 skip_evaluation = 0;
 
    top->rprio = 0;
@@ -1071,7 +1065,7 @@ cpp_parse_expr(pfile)
 	     else
 	       {
 		  new_stack = (struct operation *)xmalloc(new_size);
-		  bcopy((char *)stack, (char *)new_stack, old_size);
+		  memcpy((char *)new_stack,(char *)stack, old_size);
 	       }
 	     stack = new_stack;
 	     top = (struct operation *)((char *)new_stack + old_size);
