@@ -6,9 +6,6 @@ union hashval {
   int ival;
   char *cpval;
   DEFINITION *defn;
-#if 0
-  KEYDEF *keydef;
-#endif
 };
 
 struct hashnode {
@@ -19,7 +16,7 @@ struct hashnode {
 				   of the chain and gets deleted. */
   enum node_type type;		/* type of special token */
   int length;			/* length of token, for quick comparison */
-  U_CHAR *name;			/* the actual name */
+  unsigned char *name;			/* the actual name */
   union hashval value;		/* pointer to expansion, or whatever */
 };
 
@@ -33,8 +30,7 @@ typedef struct hashnode HASHNODE;
    politeness, for use when speed isn't so important. */
 
 #define HASHSIZE 1403
-static HASHNODE *hashtab[HASHSIZE];
 #define HASHSTEP(old, c) ((old << 2) + c)
 #define MAKE_POS(v) (v & 0x7fffffff) /* make number positive */
 
-extern HASHNODE* install PARAMS ((U_CHAR*,int,enum node_type, int,char*,int));
+extern HASHNODE* install PARAMS ((unsigned char*,int,enum node_type, int,char*,int));
