@@ -29,8 +29,6 @@ extern "C" {
 
 #define STATIC_BUFFERS
 
-typedef unsigned char U_CHAR;
-
 struct parse_file;
 typedef struct cpp_reader cpp_reader;
 typedef struct cpp_buffer cpp_buffer;
@@ -55,18 +53,6 @@ enum cpp_token {
   CPP_COMMA,    /* "," */
   CPP_SEMICOLON,/* ";" */
   CPP_3DOTS,    /* "..." */
-#if 0
-  CPP_ANDAND, /* "&&" */
-  CPP_OROR,   /* "||" */
-  CPP_LSH,    /* "<<" */
-  CPP_RSH,    /* ">>" */
-  CPP_EQL,    /* "==" */
-  CPP_NEQ,    /* "!=" */
-  CPP_LEQ,    /* "<=" */
-  CPP_GEQ,    /* ">=" */
-  CPP_PLPL,   /* "++" */
-  CPP_MINMIN, /* "--" */
-#endif
   /* POP_TOKEN is returned when we've popped a cpp_buffer. */
   CPP_POP
 };
@@ -182,7 +168,7 @@ struct cpp_reader {
   int errors;			/* Error counter for exit code */
   void *data;
 
-  U_CHAR *token_buffer;
+  unsigned char *token_buffer;
   int token_buffer_size;
 
   /* Line where a newline was first seen in a string constant.  */
@@ -274,13 +260,13 @@ struct cpp_reader {
 
 /* Make sure PFILE->token_buffer has space for at least N more characters. */
 #define CPP_RESERVE(PFILE, N) \
-  (CPP_WRITTEN (PFILE) + N > (PFILE)->token_buffer_size \
+  ((unsigned int)(CPP_WRITTEN (PFILE) + N) > (unsigned int) (PFILE)->token_buffer_size \
    && (cpp_grow_buffer (PFILE, N), 0))
 
 /* Append string STR (of length N) to PFILE's output buffer.
    Assume there is enough space. */
 #define CPP_PUTS_Q(PFILE, STR, N) \
-  (bcopy (STR, (PFILE)->limit, (N)), (PFILE)->limit += (N))
+  (memcpy ((PFILE)->limit, STR, (N)), (PFILE)->limit += (N))
 /* Append string STR (of length N) to PFILE's output buffer.  Make space. */
 #define CPP_PUTS(PFILE, STR, N) CPP_RESERVE(PFILE, N), CPP_PUTS_Q(PFILE, STR,N)
 /* Append character CH to PFILE's output buffer.  Assume sufficient space. */
@@ -551,7 +537,7 @@ typedef struct macrodef MACRODEF;
 struct macrodef
 {
   struct definition *defn;
-  U_CHAR *symnam;
+  unsigned char *symnam;
   int symlen;
 };
 
@@ -582,7 +568,7 @@ struct definition {
   int length;			/* length of expansion string */
   int predefined;		/* True if the macro was builtin or */
 				/* came from the command line */
-  U_CHAR *expansion;
+  unsigned char *expansion;
   int line;			/* Line number of definition */
   char *file;			/* File of definition */
   char rest_args;		/* Nonzero if last arg. absorbs the rest */
@@ -602,11 +588,11 @@ struct definition {
        with comma-space between them.
        The only use of this is that we warn on redefinition
        if this differs between the old and new definitions.  */
-    U_CHAR *argnames;
+    unsigned char *argnames;
   } args;
 };
 
-extern U_CHAR is_idchar[256];
+extern unsigned char is_idchar[256];
 
 /* Stack of conditionals currently in progress
    (including both successful and failing conditionals).  */
@@ -617,7 +603,7 @@ struct if_stack {
   int lineno;			/* similarly */
   int if_succeeded;		/* true if a leg of this if-group
 				    has been passed through rescan */
-  U_CHAR *control_macro;	/* For #ifndef at start of file,
+  unsigned char *control_macro;	/* For #ifndef at start of file,
 				   this is the macro name tested.  */
   enum node_type type;		/* type of last directive seen in this group */
 };
@@ -625,7 +611,7 @@ typedef struct if_stack IF_STACK_FRAME;
 
 extern void cpp_buf_line_and_col PARAMS((cpp_buffer*, long*, long*));
 extern cpp_buffer* cpp_file_buffer PARAMS((cpp_reader*));
-extern void cpp_define PARAMS ((cpp_reader*, U_CHAR*));
+extern void cpp_define PARAMS ((cpp_reader*, unsigned char*));
 
 extern void cpp_error ();
 extern void cpp_warning ();
@@ -640,12 +626,16 @@ extern void cpp_pfatal_with_name ();
 
 extern void cpp_grow_buffer PARAMS ((cpp_reader*, long));
 extern int cpp_parse_escape PARAMS ((cpp_reader*, char**));
-extern cpp_buffer* cpp_push_buffer PARAMS ((cpp_reader *, U_CHAR*, long));
+extern cpp_buffer* cpp_push_buffer PARAMS ((cpp_reader *, unsigned char*, long));
 extern cpp_buffer* cpp_pop_buffer PARAMS ((cpp_reader *));
 
-extern cpp_hashnode* cpp_lookup PARAMS ((cpp_reader*, const U_CHAR*,
+extern cpp_hashnode* cpp_lookup PARAMS ((cpp_reader*, const unsigned char*,
 					 int, int));
 
+#ifdef __EMX__
+#define PATH_SEPARATOR ';'
+#endif
+
 #ifdef __cplusplus
 }
 #endif
