@@ -1,4 +1,26 @@
 
+/*
+ * Copyright (C) 1999 Carsten Haitzler, Geoff Harrison and various contributors
+ * *
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to
+ * deal in the Software without restriction, including without limitation the
+ * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
+ * sell copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ * *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies of the Software, its documentation and marketing & publicity
+ * materials, and acknowledgment shall be given in the documentation, materials
+ * and software packages that this Software was used.
+ * *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
+ * THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
+ * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
+ * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+ */
 #define CONFIG_CONTROL 0
 #define CONFIG_TEXT 1
 #define CONFIG_MENU 2
@@ -18,6 +40,8 @@
 #define CONFIG_SLIDEOUT 16
 #define CONFIG_TOOLTIP 17
 #define CONFIG_FX 18
+#define CONFIG_IBOX 19
+#define CONFIG_EXTRAS 20
 #define CONFIG_CLASSNAME 100
 #define CONFIG_MODIFIER  101
 #define CONFIG_TYPE 102
@@ -25,6 +49,7 @@
 #define CONFIG_ACTION 104
 #define CONFIG_NEXT 105
 #define CONFIG_INHERIT 106
+#define CONFIG_ACTION_TOOLTIP 107
 #define TEXT_ORIENTATION 200
 #define TEXT_JUSTIFICATION 201
 #define TEXT_MODE 202
@@ -79,6 +104,31 @@
 #define CONTROL_RAISE_ON_NEXT_FOCUS 344
 #define CONTROL_WARP_ON_NEXT_FOCUS 345
 #define CONTROL_EDGE_FLIP_RESISTANCE 346
+#define CONTROL_SHOW_PAGERS 347
+#define CONTROL_PAGER_HIQ 348
+#define CONTROL_PAGER_SNAP 349
+#define CONTROL_ANIMATESHADING 350
+#define CONTROL_MENUONSCREEN 351
+#define CONTROL_USER_BG 1350
+#define CONTROL_PAGER_ZOOM 1351
+#define CONTROL_PAGER_TITLE 1352
+#define CONTROL_RAISE_AFTER_NEXT_FOCUS 1353
+#define CONTROL_DISPLAY_WARP 1354
+#define CONTROL_WARP_AFTER_NEXT_FOCUS 1355
+#define CONTROL_PAGER_SCANSPEED 1356
+#define CONTROL_ICONTEXT 1357
+#define CONTROL_GROUP_BORDER 1358
+#define CONTROL_GROUP_KILL 1359
+#define CONTROL_GROUP_MOVE 1360
+#define CONTROL_GROUP_RAISE 1361
+#define CONTROL_GROUP_ICONIFY 1362
+#define CONTROL_GROUP_STICK 1363
+#define CONTROL_GROUP_SHADE 1364
+#define CONTROL_GROUP_MIRROR 1365
+#define CONTROL_KDESUPPORT 1366
+#define CONTROL_CLICK_ALWAYS 1367
+#define CONTROL_SHOWROOTTOOLTIP 1368
+
 #define ICLASS_NAME 350
 #define ICLASS_NORMAL 351
 #define ICLASS_CLICKED 352
@@ -100,6 +150,7 @@
 #define ICLASS_STICKY_DISABLED 368
 #define ICLASS_STICKY_ACTIVE_DISABLED 369
 #define ICLASS_COLORMOD 370
+#define ICLASS_FILLRULE 371
 #define DESKTOP_DRAGDIR 400
 #define DESKTOP_DRAGBAR_WIDTH 401
 #define DESKTOP_DRAGBAR_ORDERING 402
@@ -160,6 +211,7 @@
 #define BORDER_INIT 505
 #define SHADEDIR 506
 #define BORDER_CHANGES_SHAPE 507
+#define BORDER_GROUP_NAME 508
 #define BUTTON_NAME 520
 #define BUTTON_ACLASS 521
 #define BUTTON_ICLASS 522
@@ -183,6 +235,7 @@
 #define BUTTON_STICKY 540
 #define BUTTON_INTERNAL 541
 #define BUTTON_SHOW 542
+#define BUTTON_LABEL 543
 #define BG_RGB 560
 #define BG_BG1 561
 #define BG_BG2 562
@@ -257,3 +310,16 @@
 
 #define CONFIG_VERSION 1001
 #define CONFIG_INVALID 9999
+
+#define CONFIG_TRANSPARENCY 2001
+#define CONFIG_SHOW_NAMES 2002
+#define CONFIG_ICON_SIZE 2003
+#define CONFIG_ICON_MODE 2004
+#define CONFIG_SCROLLBAR_SIDE 2005
+#define CONFIG_SCROLLBAR_ARROWS 2006
+#define CONFIG_AUTOMATIC_RESIZE 2007
+#define CONFIG_SHOW_ICON_BASE 2008
+#define CONFIG_SCROLLBAR_AUTOHIDE 2009
+#define CONFIG_COVER_HIDE 2010
+#define CONFIG_RESIZE_ANCHOR 2011
+#define CONFIG_IB_ANIMATE 2012
